## ----setup, include = FALSE----------------------------------------------
library(lvplot)
library(RColorBrewer)
library(dplyr)
library(ggplot2)
library(scales)

greys <- rev(RColorBrewer::brewer.pal(9, "Greys"))
oranges <- RColorBrewer::brewer.pal(3, "Oranges")
colors <- c("white", greys[2:4], oranges[3], greys[4:6], oranges[2],
      greys[6:8], oranges[1], greys[8:9])

#cols <- c("white",brewer.pal(9, "Greys"), "Red", "Pink")
#reds <- brewer.pal(5, "Reds")[-1]
#cols <- c(cols[1:3], reds[1], cols[4:6], reds[2], cols[7:9], reds[3], cols[10:11])
cols <- colors

comma <- function(x) format(x, big.mark = ",", digits = 2)

set.seed(14101979)

lv_horiz <- function(x, xlab = "", width.method="linear", median.col="white", ...) {
  LVboxplot(x, xlab = xlab, horizontal = TRUE, col = cols, width.method=width.method, median.col = median.col)
}
bp_horiz <- function(x, xlab = "", ...) {
  bcp <- boxplot.stats(x)
  xrange <- range(c(bcp$stats, bcp$out))

  plot(xrange, c(0.7, 1.3), type = "n", axes = FALSE, ylab = "", xlab = xlab)
  box()
  rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "grey90")
  grid(lty = 1, col = "white", ny = NA)
  axis(1)
  boxplot(x, horizontal = TRUE, add = TRUE, col = "white")
}

## ----taxi-data, include = FALSE------------------------------------------
ontime$UniqueCarrier <- reorder(ontime$UniqueCarrier, ontime$UniqueCarrier,
  function(x) -length(x)
)
bycarrier <- ontime %>% group_by(UniqueCarrier) %>% summarize(
  n = n(),
  meantt = mean(TaxiIn + TaxiOut, na.rm = TRUE),
  medtt = median(TaxiIn + TaxiOut, na.rm = TRUE)
)

## ----fig-taxi-1, echo=FALSE, fig.width=10, fig.height=5, out.width='\\textwidth'----
ggplot(ontime, aes(UniqueCarrier, TaxiOut + TaxiIn)) +
  geom_boxplot(na.rm = TRUE) +
  scale_y_sqrt(breaks = c(10, 50, 100, 150, 200, 250)) +
  xlab("Carrier") +
  ylab("Taxi Time (in minutes)") +
  theme_bw()

## ----fig-taxi-2, echo=FALSE, fig.width=10, fig.height=5.5, out.width='\\textwidth'----
ggplot(ontime, aes(UniqueCarrier, TaxiOut + TaxiIn)) +
  geom_lv(aes(fill = ..LV..)) +
  scale_fill_lv() +
  scale_y_sqrt(breaks = c(10, 50, 100, 150, 200, 250)) +
  xlab("Carrier") +
  ylab("Taxi Time (in minutes)") +
  theme_bw()

## ----boxplots-random, echo=FALSE, fig.width=6, fig.height=3, out.width='\\linewidth', warning=FALSE----
n <- 10000

rn <- rnorm(n)
re <- rexp(n)
ru <- runif(n)

## ----bp-1, echo=FALSE, fig.width=6, fig.height=1, out.width='\\linewidth', warning=FALSE----
par(mfrow = c(1,3), mar = c(4.1, 1, 0, 1))
bp_horiz(rn)
bp_horiz(re)
bp_horiz(ru)

## ----lv-1, echo=FALSE, fig.width=6, fig.height=1, out.width='\\linewidth', warning=FALSE----
par(mfrow = c(1,3), mar = c(4.1, 1, 0, 1))

lv_horiz(rn)
lv_horiz(re)
lv_horiz(ru)

## ----lv-2, echo=FALSE, fig.width=6, fig.height=1, out.width='\\linewidth', warning=FALSE----
par(mfrow = c(1,3), mar = c(4.1, 1, 0, 1))
lv_horiz(rn, "Gaussian, n=10,000", width.method = "area")
lv_horiz(re, xlab = "Exponential, n=10,000", width.method = "area")
lv_horiz(ru, xlab = "Uniform, n=10,000", width.method = "area")

## ----letter-val, echo=FALSE, warning=FALSE, message=FALSE, fig.width=6, fig.height=4.75, out.width='0.6\\linewidth'----
highres <- expand.grid(
  factor = c(0.1,0.2,0.25, 0.5),
  k = seq(1, 21, by = 0.1)
) %>% mutate(
  pi = 2 ^ -k,
  sefactor = sqrt(pi*(1 - pi)) / dnorm(qnorm(pi)),
  n = (2 * sefactor / factor) ^ 2,
  factor = factor(factor)
)
res <- subset(highres, k %in% seq(1, 21, by = 2))

ggplot(res, aes(k, n, colour = factor)) +
  geom_point(aes(shape = factor), size = 3.5) +
  geom_line(data = highres) +
  xlab("Letter Value k") +
  scale_colour_brewer(palette = "Set2") +
  scale_y_log10("Number of Observations, n",
    breaks = scales::trans_breaks("log10", function(x) 10 ^ x),
    labels = scales::trans_format("log10", scales::math_format(10 ^ .x))
  ) +
  theme_bw() +
  theme(legend.position = "bottom")

## ----t-dist, echo=FALSE, fig.width=6, fig.height=2, out.width='\\linewidth'----
par(mfrow = c(2,3), mar = c(4.1, 1, 0, 1))
n <- 10000
t2 <- rt(n, df = 2)
t3 <- rt(n, df = 3)
t9 <- rt(n, df = 9)

bp_horiz(t2)
bp_horiz(t3)
bp_horiz(t9)
lv_horiz(t2, "t distribution, df=2, n=10,000")
lv_horiz(t3, "t distribution, df=3, n=10,000")
lv_horiz(t9, "t distribution, df=9, n=10,000")

## ----countypop, echo=FALSE, fig.width=8, fig.height=3.5, out.width='0.9\\linewidth'----

#pdf("../images/counties-qq.pdf", width = 6, height = 4)
par(mfrow = c(2,2), mar = c(4.1,.5,2,0.5))#mar = c(4.1, 3, 2, 1))

bp_horiz(census$totalpop / 1e6, "total population (millions)")
bp_horiz(log(census$totalpop), "(log) total population")

lv_horiz(census$totalpop  / 1e6, "total population (millions)")
lv_horiz(log(census$totalpop), "(log) total population")

## ----simu-data, echo=FALSE, results='hide', cache=TRUE-------------------
frame <- data.frame(expand.grid(k=c(0:5, 5*(2:10)), n1=1500))
frame$n2 <- with(frame, n1/100*k)
frame$n1 <- with(frame, n1- n2)

dframe <- NULL
set.seed(20120416)
for (i in 1:10) {
  x <- c(rnorm(frame[i,]$n1), 4 + rnorm(frame[i,]$n2))
  dframe <- rbind(dframe, data.frame(k=frame[i,]$k, x=x))
}

## ----sim-hist, dependson='simu-data', echo=FALSE, fig.width=12, fig.height=6, out.width='0.9\\linewidth'----
dframe$klabel <- sprintf("Contamination: %d%%", dframe$k)
dframe$klabel <- factor(dframe$klabel)
dframe$klabel <- reorder(dframe$klabel, dframe$k)
qplot(data=dframe, x, geom="histogram", binwidth=0.25) +
  facet_wrap(facets=~klabel, ncol=5) +
  theme_bw()
#ggsave("images/xpl-histogram.pdf", width=12, height=6)

## ----sim-xpl-box, dependson='simu-data', echo=FALSE, fig.width=8.8, fig.height=3.3, out.width='.9\\linewidth'----
ggplot(dframe, aes(factor(k), x)) +
  geom_boxplot() +
  xlab("Amount of contaminated data (in percent)") +
  ylab(NULL) +
  theme_bw()

# ggsave("images/xpl-boxplot.pdf", width=10, height=5)

## ----sim-xpl-lv, dependson='simu-data', echo=FALSE, fig.width=8, fig.height=3, out.width='\\linewidth', warning=FALSE----
ggplot(dframe,
  aes(factor(k), x)) +
  geom_lv(aes(fill = ..LV..)) +
  scale_fill_lv() +
  xlab("Amount of contaminated data (in percent)") +
  ylab(NULL) +
  theme_bw()

## ----sim-xpl-lv-2, dependson='simu-data', echo=FALSE, fig.width=8, fig.height=3, out.width='\\linewidth', warning=FALSE----
ggplot(dframe, aes(factor(k), x)) +
  geom_lv(aes(fill = ..LV..), width.method = "area", width = 2) +
  scale_fill_lv() +
  xlab("Amount of contaminated data (in percent)") +
  ylab("") + theme_bw()

## ----carrier-lv, echo=FALSE, out.width='.8\\linewidth', fig.height=5, fig.width=10, message=FALSE----
ggplot(ontime, aes(UniqueCarrier, CarrierDelay)) +
  geom_lv(aes(fill = ..LV..)) +
  scale_fill_lv() +
  scale_y_sqrt(breaks = c(50, 100, 500, 1000, 1500, 2000)) +
  ylab("Carrier Delay (in minutes)") +
  xlab("Carrier") +
  theme_bw()

## ----nas-lv, out.width='.8\\linewidth', echo=FALSE, fig.height=5, fig.width=10, message=FALSE----
ggplot(ontime, aes(UniqueCarrier, NASDelay)) +
  geom_lv(aes(fill = ..LV..)) +
  scale_fill_lv() +
  scale_y_sqrt(breaks = c(50, 100, 500, 1000, 1500, 2000)) +
  xlab("Carrier") +
  ylab("NAS Delay (in minutes)") +
  theme_bw()

## ----weather-lv, out.width='.8\\linewidth', echo=FALSE, fig.height=5, fig.width=10, message=FALSE----
ggplot(ontime, aes(UniqueCarrier, WeatherDelay)) +
  geom_lv(aes(fill = ..LV..)) +
  scale_fill_lv() +
  scale_y_sqrt("Carrier Delay (in minutes)",
    breaks = c(50, 100, 500, 1000, 1500, 2000)) +
  xlab("Carrier") +
  theme_bw()

